# Broker System

This is a python module for using the broker system.

## Installation

For macOS and Linux:

```shell
pip3 install brokersystem
```

For Windows:

```shell
pip install brokersystem
```

